import { errorKeys } from './errorCodes.js';
import { NonEmptyArray } from './nonEmptyArray.js';
/**
 * Remove escape sequences from a single value string.
 * Essentially just understands \n, as almost all other escaping is either unnecessary or illegal.
 * @param s Escaped (formerly quoted) parameter value string
 * @returns Unescaped string
 */
export declare function scanSingleValue(s: string, errorCallback?: (error: errorKeys) => void): string;
/**
 * Handle escape sequences in a quoted parameter string.
 * - RFC6868 (`^^`, `^'`, and `^n`)
 * - Nag about `\n`
 * @param s Escaped (formerly quoted) parameter value string
 * @returns Unescaped string
 */
export declare function scanSingleParamValue(s: string, errorCallback: ((error: errorKeys) => void) | null): string;
/**
 * Splits a property value at semicolons *OR* commas.
 * Observes escaped commas/semicolons, and replaces \n.
 * @param s A property's value
 * @param splitChar A semicolon or comma
 * @returns The array of unescaped strings
 */
export declare function scan1DValue(s: string, splitChar: ',' | ';'): NonEmptyArray<string>;
/**
 * Splits a property value at semicolons (level 1) and the part between the semicolons at commas (level 2).
 * Observes escaped commas/semicolons, and replaces \n.
 * @param s A property's value
 * @returns 2D string array
 */
export declare function scan2DValue(s: string): NonEmptyArray<NonEmptyArray<string>>;
