import { scan1DValue, scan2DValue, scanSingleValue } from '../scan.js';
describe('Property value scanning', function () {
    it('should escape single values', function () {
        expect(scanSingleValue('A\\nB\\\\nC')).toStrictEqual('A\nB\\nC');
    });
    it('should split 1D values on commas', function () {
        expect(scan1DValue('A,B', ',')).toStrictEqual(['A', 'B']);
    });
    it('should split 1D values on semicolons', function () {
        expect(scan1DValue('A;B', ';')).toStrictEqual(['A', 'B']);
    });
    it('should not split at escaped or different', function () {
        expect(scan1DValue('A\\,B;C\\;D,E\\\\,F', ',')).toStrictEqual([
            'A,B;C;D',
            'E\\',
            'F',
        ]);
    });
    it('should understand newlines', function () {
        expect(scan1DValue('A\\nB,C\\\\nD', ',')).toStrictEqual(['A\nB', 'C\\nD']);
    });
    it('should split 2D values', function () {
        expect(scan2DValue('A,B;C;D,E;F;;,G')).toStrictEqual([
            ['A', 'B'],
            ['C'],
            ['D', 'E'],
            ['F'],
            [''],
            ['', 'G'],
        ]);
    });
    it('should understand escaped 2D values', function () {
        expect(scan2DValue('A\\,B\\;C;D,E\\\\;F\\n;;,G')).toStrictEqual([
            ['A,B;C'],
            ['D', 'E\\'],
            ['F\n'],
            [''],
            ['', 'G'],
        ]);
    });
});
//# sourceMappingURL=scan.test.js.map