import { Nag, VCardNagAttributes } from './errors.js';
import { NonEmptyArray } from './nonEmptyArray.js';
import { Flatten, TypeOf } from './runtimeTypes.js';
export declare const knownParameters: {
    LANGUAGE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    VALUE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    PREF: import("./runtimeTypes.js").RuntimeTypeAnnotation<number>;
    ALTID: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    PID: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    TYPE: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    MEDIATYPE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CALSCALE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    SORT_AS: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    GEO: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    TZ: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    LABEL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CC: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    INDEX: import("./runtimeTypes.js").RuntimeTypeAnnotation<number>;
    LEVEL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
};
export declare type KnownParameterNames = keyof typeof knownParameters;
export declare const isKnownParameter: (key: string) => key is "LANGUAGE" | "VALUE" | "PREF" | "ALTID" | "PID" | "TYPE" | "MEDIATYPE" | "CALSCALE" | "SORT_AS" | "GEO" | "TZ" | "LABEL" | "CC" | "INDEX" | "LEVEL";
export declare type VCardParameters = Flatten<{
    [k in KnownParameterNames]?: TypeOf<typeof knownParameters[k]>;
} & {
    x?: Record<string, NonEmptyArray<string>>;
}>;
export declare const knownProperties: {
    BEGIN: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    VERSION: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    END: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    FN: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    PRODID: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    UID: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    REV: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    KIND: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    N: import("./runtimeTypes.js").RuntimeTypeAnnotation<{
        familyNames: NonEmptyArray<string>;
        givenNames: NonEmptyArray<string>;
        additionalNames: NonEmptyArray<string>;
        honorificPrefixes: NonEmptyArray<string>;
        honorificSuffixes: NonEmptyArray<string>;
    }>;
    BDAY: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    ANNIVERSARY: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    GENDER: import("./runtimeTypes.js").RuntimeTypeAnnotation<{
        sex: string;
        text?: string | undefined;
    }>;
    BIRTHPLACE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    DEATHPLACE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    DEATHDATE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CLIENTPIDMAP: import("./runtimeTypes.js").RuntimeTypeAnnotation<{
        pidRef: number;
        uri: string;
    }>;
    SOURCE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    XML: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    NICKNAME: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    PHOTO: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    ADR: import("./runtimeTypes.js").RuntimeTypeAnnotation<{
        postOfficeBox?: NonEmptyArray<string> | undefined;
        extendedAddress?: NonEmptyArray<string> | undefined;
        streetAddress?: NonEmptyArray<string> | undefined;
        locality?: NonEmptyArray<string> | undefined;
        region?: NonEmptyArray<string> | undefined;
        postalCode?: NonEmptyArray<string> | undefined;
        countryName?: NonEmptyArray<string> | undefined;
    }>;
    TEL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    EMAIL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    IMPP: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    LANG: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    TZ: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    GEO: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    TITLE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    ROLE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    LOGO: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    ORG: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    MEMBER: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    RELATED: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CATEGORIES: import("./runtimeTypes.js").RuntimeTypeAnnotation<NonEmptyArray<string>>;
    NOTE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    SOUND: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    URL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    KEY: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    FBURL: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CALADRURI: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CALURI: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    CONTACT_URI: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    EXPERTISE: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    HOBBY: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    INTEREST: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
    ORG_DIRECTORY: import("./runtimeTypes.js").RuntimeTypeAnnotation<string>;
};
export declare type KnownPropertyNames = keyof typeof knownProperties;
export declare const isKnownProperty: (key: string) => key is "N" | "ADR" | "GENDER" | "CLIENTPIDMAP" | "GEO" | "TZ" | "BEGIN" | "VERSION" | "END" | "FN" | "PRODID" | "UID" | "REV" | "KIND" | "BDAY" | "ANNIVERSARY" | "BIRTHPLACE" | "DEATHPLACE" | "DEATHDATE" | "SOURCE" | "XML" | "NICKNAME" | "PHOTO" | "TEL" | "EMAIL" | "IMPP" | "LANG" | "TITLE" | "ROLE" | "LOGO" | "ORG" | "MEMBER" | "RELATED" | "CATEGORIES" | "NOTE" | "SOUND" | "URL" | "KEY" | "FBURL" | "CALADRURI" | "CALURI" | "CONTACT_URI" | "EXPERTISE" | "HOBBY" | "INTEREST" | "ORG_DIRECTORY";
export declare const exactlyOnceProperties: {
    BEGIN: string;
    VERSION: string;
    END: string;
};
export declare type ExactlyOncePropertyNames = keyof typeof exactlyOnceProperties;
export declare type ExactlyOnceProperties = Pick<typeof knownProperties, ExactlyOncePropertyNames>;
export declare const isExactlyOnceProperty: (key: string) => key is "BEGIN" | "VERSION" | "END";
export declare const atLeastOnceProperties: {
    FN: string;
};
export declare type AtLeastOncePropertyNames = keyof typeof atLeastOnceProperties;
export declare type AtLeastOnceProperties = Pick<typeof knownProperties, AtLeastOncePropertyNames>;
export declare const isAtLeastOnceProperty: (key: string) => key is "FN";
export declare const atMostOnceProperties: {
    PRODID: number;
    UID: number;
    KIND: number;
    N: number;
    BDAY: number;
    ANNIVERSARY: number;
    GENDER: number;
    REV: number;
    BIRTHPLACE: number;
    DEATHPLACE: number;
    DEATHDATE: number;
};
export declare type AtMostOncePropertyNames = keyof typeof atMostOnceProperties;
export declare type AtMostOnceProperties = Pick<typeof knownProperties, AtMostOncePropertyNames>;
export declare const isAtMostOnceProperty: (key: string) => key is "N" | "GENDER" | "PRODID" | "UID" | "REV" | "KIND" | "BDAY" | "ANNIVERSARY" | "BIRTHPLACE" | "DEATHPLACE" | "DEATHDATE";
export declare type AnyCardinalityProperties = Omit<typeof knownProperties, keyof ExactlyOnceProperties | keyof AtLeastOnceProperties | keyof AtMostOnceProperties>;
export declare type SingleVCardProperty<ValueType> = {
    group?: string;
    parameters?: VCardParameters;
    value: ValueType;
};
export declare type VCardSingles<Selection extends Partial<typeof knownProperties>> = {
    [k in keyof Selection & keyof typeof knownProperties]: SingleVCardProperty<TypeOf<typeof knownProperties[k]>>;
};
export declare type VCardMultiples<Selection extends Partial<typeof knownProperties>> = {
    [k in keyof Selection & keyof typeof knownProperties]: NonEmptyArray<SingleVCardProperty<TypeOf<typeof knownProperties[k]>>>;
};
export declare type VCard4 = Flatten<VCardSingles<ExactlyOnceProperties> & Partial<VCardSingles<AtMostOnceProperties>> & VCardMultiples<AtLeastOnceProperties> & Partial<VCardMultiples<AnyCardinalityProperties>> & {
    x?: Record<string, NonEmptyArray<SingleVCardProperty<string>>>;
    nags?: NonEmptyArray<Nag<VCardNagAttributes>>;
    hasErrors: boolean;
    unparseable?: NonEmptyArray<string>;
}>;
